package pro.skywalking.utils;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;

public class CheckParam {

   private static final Pattern LONG_TIME_PATTERN = Pattern.compile("^1[0-9]{9}$");


   public static boolean isNull(List list) {
      return isNull((List)list) && list.isEmpty();
   }

   public static boolean isNull(String str) {
      return null == str || "".equals(str.trim()) || "null".equals(str.trim()) || "undefined".equals(str.trim());
   }

   public static boolean isNull(Object obj) {
      return null == obj || isNull((String)obj.toString());
   }

   public static boolean isInteger(String str) {
      return !isNull((String)str) && str.matches("^-?\\d+$");
   }

   public static boolean isInteger(Object obj) {
      return obj != null && obj.toString().matches("^-?\\d+$");
   }

   public static boolean isIdCard(String str) {
      Integer idCardLength = Integer.valueOf(18);
      if(str != null && str.length() == idCardLength.intValue()) {
         int[] wArray = new int[]{7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2};
         int sum = 0;

         for(int modNumber = 0; modNumber < str.length() - 1; ++modNumber) {
            sum += (new Integer(str.substring(modNumber, modNumber + 1))).intValue() * wArray[modNumber];
         }

         Integer var6 = Integer.valueOf(11);
         String[] sumsArray = new String[]{"1", "0", "X", "9", "8", "7", "6", "5", "4", "3", "2"};
         return sumsArray[sum % Integer.valueOf(var6.intValue()).intValue()].equals(str.substring(str.length() - 1, str.length()));
      } else {
         return false;
      }
   }

   public static boolean isPassportCard(String str) {
      return !isNull((String)str) && str.matches("(P\\d{7})|(G\\d{8})");
   }

   public static boolean isGuideCard(String str) {
      return !isNull((String)str) && str.matches("^D(-)?\\d{4}(-)?\\d{6}");
   }

   public static boolean isMobile(String str) {
      return !isNull((String)str) && str.matches("^((13[0-9])|(14[0-9])|(15[0-9])|(16[0-9])|(17[0-9])|(18[0-9])|(19[0-9]))\\d{8}$");
   }

   public static boolean isBusNumber(String str) {
      return !isNull((String)str) && str.matches("^[一-龥|WJ]{1}[A-Z0-9]{6}$");
   }

   public static boolean isPhone(String str) {
      return !isNull((String)str) && str.matches("^(0[0-9]{2,3}\\-?)?([2-9][0-9]{6,7})+(\\-[0-9]{1,4})?$");
   }

   public static boolean isDouble(String str) {
      return !isNull((String)str) && str.matches("^-?([1-9]\\d*\\.\\d*|0\\.\\d*[1-9]\\d*|0?\\.0+|0)$");
   }

   public static boolean isEmail(String str) {
      return !isNull((String)str) && str.matches("^[0-9a-z][a-z0-9\\._-]{1,}@[a-z0-9-]{1,}[a-z0-9]\\.[a-z\\.]{1,}[a-z]$");
   }

   public static boolean isNum(String str) {
      return !isNull((String)str) && str.matches("^[-+]?(([0-9]+)([.]([0-9]+))?|([.]([0-9]+))?)$");
   }

   public static boolean isNotNullAndNotNum(String str) {
      return !isNull((String)str) && !isNum((String)str);
   }

   public static boolean isNum(Object obj) {
      return obj != null && isNum((String)obj.toString());
   }

   public static final String getImageFileType(File f) {
      if(isImage(f)) {
         try {
            ImageInputStream e = ImageIO.createImageInputStream(f);
            Iterator iter = ImageIO.getImageReaders(e);
            if(!iter.hasNext()) {
               return null;
            } else {
               ImageReader reader = (ImageReader)iter.next();
               e.close();
               return reader.getFormatName();
            }
         } catch (IOException var4) {
            return null;
         } catch (Exception var5) {
            return null;
         }
      } else {
         return null;
      }
   }

   public static final boolean isImage(File file) {
      boolean flag = false;

      try {
         BufferedImage e = ImageIO.read(file);
         int width = e.getWidth();
         int height = e.getHeight();
         if(width != 0 && height != 0) {
            flag = true;
         } else {
            flag = false;
         }
      } catch (IOException var5) {
         flag = false;
      } catch (Exception var6) {
         flag = false;
      }

      return flag;
   }

   public static final boolean isDate(String str) {
      SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
      sdf.setLenient(false);

      try {
         sdf.parse(str);
         return true;
      } catch (Exception var3) {
         return false;
      }
   }

   public static final boolean isDateYm(String str) {
      SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM");
      sdf.setLenient(false);

      try {
         sdf.parse(str);
         return true;
      } catch (Exception var3) {
         return false;
      }
   }

   public static final boolean isDateY(String str) {
      SimpleDateFormat sdf = new SimpleDateFormat("yyyy");
      sdf.setLenient(false);

      try {
         sdf.parse(str);
         return true;
      } catch (Exception var3) {
         return false;
      }
   }

   public static final boolean isDatetime(String str) {
      SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
      sdf.setLenient(false);

      try {
         sdf.parse(str);
         return true;
      } catch (Exception var3) {
         return false;
      }
   }

   public static final boolean isDatetime(Object obj) {
      return obj != null && isDatetime((String)obj.toString());
   }

   public static final boolean isDatetimeNoSecond(String str) {
      SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm");
      sdf.setLenient(false);

      try {
         sdf.parse(str);
         return true;
      } catch (Exception var3) {
         return false;
      }
   }

   public static final boolean isDateTime(Object obj, String pattern) {
      if(obj != null && pattern != null) {
         SimpleDateFormat sdf = new SimpleDateFormat(pattern);
         sdf.setLenient(false);

         try {
            if(obj.getClass() != Date.class && !(obj instanceof Date)) {
               sdf.parse(obj.toString());
            } else {
               Date e = (Date)obj;
               sdf.format(e);
            }

            return true;
         } catch (Exception var4) {
            return false;
         }
      } else {
         return false;
      }
   }

   public static final Boolean isLongTime(Long time) {
      String time2 = time.toString();
      Matcher m = LONG_TIME_PATTERN.matcher(time2);
      return Boolean.valueOf(m.matches());
   }

   public static void main(String[] args) {
   }

}
